package com.ruoyi.quartz.mapper;

import com.ruoyi.quartz.domain.c_rb_product_price;
import com.ruoyi.quartz.domain.c_rb_productbase_price;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

/**
 * Created by xuxueli on 16/9/30.
 */
public interface SapTjMapper {
    /**
     * 获取红本调价版本
     * @return
     */
    String selRbVersionUid();

    /**
     * 获取本地红本调价版本
     * @return
     */
    String selLocVersionUid();

    /**
     * 获取红本价格
     * @param rbVersionUid
     * @return
     */
    List<c_rb_product_price> getProductPriceList(String rbVersionUid);

    /**
     * 获取红本成本价格
     * @param rbVersionUid
     * @return
     */
    List<c_rb_productbase_price> getProductBasePriceList(String rbVersionUid);

    /**
     * 删除本地红本价格表
     */
    void deleteLocProductPrice();

    /**
     * 删除本地红本成本价格表
     */
    void deleteLocProductBasePrice();

    /**
     * RbProductPrice表是否有更新
     * @param rbVersionUid
     * @return
     */
    String selRbProductPriceVersionUid(String rbVersionUid);

    /**
     * RbProductBasePrice表是否有更新
     * @param rbVersionUid
     * @return
     */
    String selRbProductBasePriceVersionUid(String rbVersionUid);

    /**
     * 更新本地c_rb_version表
     * @param rbVersionUid
     */
    void updateLocRbVersion(String rbVersionUid);
}
